==> react-native-rtc-1.0.0.tgz: package/android/src/main/java/com/volcengine/reactnative/vertc/vod/VideoAudioProcessor.java <==
// Copyright © 2022 BytePlusRTC All rights reserved.
// SPDX-License-Identifier: MIT

package com.volcengine.reactnative.vertc.vod;

import android.opengl.EGLContext;
import android.util.Log;

import com.ss.bytertc.engine.RTCVideo;
import com.ss.bytertc.engine.ScreenVideoEncoderConfig;
import com.ss.bytertc.engine.data.ColorSpace;
import com.ss.bytertc.engine.data.ReturnStatus;
import com.ss.bytertc.engine.data.VideoPixelFormat;
import com.ss.bytertc.engine.data.VideoRotation;
import com.ss.bytertc.engine.video.builder.GLTextureVideoFrameBuilder;
import com.ss.ttm.player.AudioProcessor;


import java.nio.ByteBuffer;
import java.util.concurrent.TimeUnit;

public class VideoAudioProcessor extends AudioProcessor {
    public String TAG = "VideoAudioProcessor";

    private org.json.JSONObject mOptions;
    private final VodAudioProcessor processor;
    private final RTCVideo mRTCEngine;
    
    public VideoAudioProcessor(RTCVideo engine, org.json.JSONObject options) {
        processor = new VodAudioProcessor(engine);
        mRTCEngine = engine;  
        mOptions = options;
    }
   
    public void updateScreenConfig(int width, int height) {
        ScreenVideoEncoderConfig videoEncoderConfig = new ScreenVideoEncoderConfig();
        videoEncoderConfig.frameRate = 30;
        videoEncoderConfig.maxBitrate = -1;
        videoEncoderConfig.width = width;
        videoEncoderConfig.height = height;
        videoEncoderConfig.encodePreference = ScreenVideoEncoderConfig.EncoderPreference.MaintainFramerate;
        mRTCEngine.setScreenVideoEncoderConfig(videoEncoderConfig);
    }

    @Override
    public void audioOpen(int sampleRate, int channelCount, int duration, int format) {
        processor.audioOpen(sampleRate, channelCount);
    }

    @Override
    public void audioProcess(ByteBuffer[] byteBuffers, int samples, long timestamp) {
      processor.audioProcess(byteBuffers, samples, timestamp);
    }

    @Override
    public void audioClose() {

    }

    @Override
    public void audioRelease(int i) {

    }

    public void onFrameAvailable(EGLContext eglContext, int oesTextureId, float[] transformMatrix, int width, int height) {
     long timeStampUs = System.currentTimeMillis() * TimeUnit.MILLISECONDS.toNanos(1);
     GLTextureVideoFrameBuilder builder = new GLTextureVideoFrameBuilder(VideoPixelFormat.TEXTURE_OES)
       .setTextureID(oesTextureId)
       .setWidth(width)
       .setHeight(height)
       .setRotation(VideoRotation.VIDEO_ROTATION_0)
       .setTextureMatrix(transformMatrix)
       .setTimeStampUs(timeStampUs)
       .setColorSpace(ColorSpace.UNKNOWN)
       .setEGLContext(eglContext);
     int ret_status = mRTCEngine.pushScreenVideoFrame(builder.build());
     boolean result = ret_status == ReturnStatus.RETURN_STATUS_SUCCESS.value()
       || ret_status == ReturnStatus.RETURN_STATUS_VIDEO_TIMESTAMP_WARNING.value();
     if (!result) {
       Log.d(TAG, "pushScreenVideoFrame fail: " + ret_status);
     }
    }
    
    public void destory() {
      
    }
}

==> react-native-rtc-1.0.1.tgz: package/android/src/main/java/com/volcengine/reactnative/vertc/vod/VideoAudioProcessor.java <==
// Copyright © 2022 BytePlusRTC All rights reserved.
// SPDX-License-Identifier: MIT

package com.volcengine.reactnative.vertc.vod;

import android.opengl.EGLContext;
import android.util.Log;

import com.ss.bytertc.engine.RTCVideo;
import com.ss.bytertc.engine.ScreenVideoEncoderConfig;
import com.ss.bytertc.engine.data.ColorSpace;
import com.ss.bytertc.engine.data.ReturnStatus;
import com.ss.bytertc.engine.data.VideoPixelFormat;
import com.ss.bytertc.engine.data.VideoRotation;
import com.ss.bytertc.engine.video.builder.GLTextureVideoFrameBuilder;
import com.ss.ttm.player.AudioProcessor;


import java.nio.ByteBuffer;
import java.util.concurrent.TimeUnit;

public class VideoAudioProcessor extends AudioProcessor {
  public String TAG = "VideoAudioProcessor";
  
  private final VodAudioProcessor processor;
    private final RTCVideo mRTCEngine;

    public VideoAudioProcessor(RTCVideo engine) {
        processor = new VodAudioProcessor(engine);
        mRTCEngine = engine;  
    }
   
    public void updateScreenConfig(int width, int height) {
        ScreenVideoEncoderConfig videoEncoderConfig = new ScreenVideoEncoderConfig();
        videoEncoderConfig.frameRate = 30;
        videoEncoderConfig.maxBitrate = -1;
        videoEncoderConfig.width = width;
        videoEncoderConfig.height = height;
        videoEncoderConfig.encodePreference = ScreenVideoEncoderConfig.EncoderPreference.MaintainFramerate;
        mRTCEngine.setScreenVideoEncoderConfig(videoEncoderConfig);
//        mRTCEngine.publishScreen(RTCEngine.MediaStreamType.RTC_MEDIA_STREAM_TYPE_BOTH);
    }

    @Override
    public void audioOpen(int sampleRate, int channelCount, int duration, int format) {
        processor.audioOpen(sampleRate, channelCount);
    }

    @Override
    public void audioProcess(ByteBuffer[] byteBuffers, int samples, long timestamp) {
      processor.audioProcess(byteBuffers, samples, timestamp);
    }

    @Override
    public void audioClose() {

    }

    @Override
    public void audioRelease(int i) {

    }

    public void onFrameAvailable(EGLContext eglContext, int oesTextureId, float[] transformMatrix, int width, int height) {
     long nanoTime = System.currentTimeMillis() * TimeUnit.MILLISECONDS.toNanos(1);
     GLTextureVideoFrameBuilder builder = new GLTextureVideoFrameBuilder(VideoPixelFormat.TEXTURE_OES)
       .setTextureID(oesTextureId)
       .setWidth(width)
       .setHeight(height)
       .setRotation(VideoRotation.VIDEO_ROTATION_0)
       .setTextureMatrix(transformMatrix)
       .setTimeStampUs(nanoTime)
       .setColorSpace(ColorSpace.UNKNOWN)
       .setEGLContext(eglContext);
     int ret_status = mRTCEngine.pushScreenVideoFrame(builder.build());
     boolean result = ret_status == ReturnStatus.RETURN_STATUS_SUCCESS.value()
       || ret_status == ReturnStatus.RETURN_STATUS_VIDEO_TIMESTAMP_WARNING.value();
     if (!result) {
       Log.d(TAG, "pushScreenVideoFrame fail: " + ret_status);
     }
    }
    
    public void destory() {
      
    }
}
